@@ -83,6 +83,7 @@ Bayonne::statetab Bayonne::states[] = {
 	{"join", &BayonneSession::stateJoin, 'j'},
 	{"accept", &BayonneSession::stateWait, 'w'},
 	{"connect", &BayonneSession::stateConnect, 'd'},
+	{"hunting", &BayonneSession::stateHunting, 'o'},
 	{"sleep", &BayonneSession::stateSleep, 's'},
 	{"start", &BayonneSession::stateStart, 's'},
 	{"hangup", &BayonneSession::stateHangup, 'h'},
@@ -682,7 +683,7 @@ void Bayonne::errlog(const char *level, const char *fmt, ...)
 	if(Bayonne::server) 	                                                 
 		Bayonne::server->errlog(level, buffer);
 }
-
+	
 BayonneSession *Bayonne::startDialing(const char *dial, const char *name, const char *caller, const char *display, BayonneSession *parent)
 {
 	ScriptImage *img;
@@ -697,6 +698,7 @@ BayonneSession *Bayonne::startDialing(const char *dial, const char *name, const
 	Event event;
 	unsigned idx = 0, count;
 	timeslot_t pos;
+	bool ext = false;
 
 	if(!caller || !*caller)
 	{
@@ -827,14 +829,36 @@ protocol:
 		sel = scr->select;
 
 	cp = d->getLast("urlprefix");
-	if(sel && *sel->args[0] == '-')
+	if(cp && *cp && !strnicmp(dial, cp, strlen(cp)))
+		dial += strlen(cp);
+
+	if(d->isExternal(dial))
 	{
+		ext = true;
 		sel = NULL;
 		cp = "";
 	}
+	else if(sel)
+	{
+moreproxies:
+		while(sel->args[idx])
+		{
+			if(d->isReachable(sel->args[idx]))
+				break;
+			++idx;
+		}
+		if(!sel->args[idx])
+		{
+			if(!sel->next)
+				return NULL;
+			sel = sel->next;
+			idx = 0;
+			goto moreproxies;
+		}
+	}
 
 	if(sel)
-		snprintf(buffer, sizeof(buffer), "%s%s@%s", cp, dial, sel->args[0]); 
+		snprintf(buffer, sizeof(buffer), "%s%s@%s", cp, dial, sel->args[idx]); 
 	else
 		snprintf(buffer, sizeof(buffer), "%s%s", cp, dial);
 
@@ -843,7 +867,10 @@ protocol:
 
 start:
 	memset(&event, 0, sizeof(event));
-	event.id = START_OUTGOING;
+	if(ext)
+		event.id = START_RINGING;
+	else
+		event.id = START_OUTGOING;
 	event.start.img = img;
 	event.start.scr = scr;
 	event.start.dialing = dial;
