@@ -202,6 +202,7 @@ public:
 		STATE_JOIN,
 		STATE_WAIT,
 		STATE_CONNECT,
+		STATE_HUNTING,
 		STATE_SLEEP,
 		STATE_START,
 		STATE_HANGUP,
@@ -290,6 +291,8 @@ public:
 		EXIT_PARTING,		// exit a join...
 		NULL_EVENT,		// generic null event pusher
 		ERROR_STATE,		// generic enter with error
+		ENTER_HUNTING,
+		EXIT_HUNTING,
 
 		// primary session control events
 
@@ -298,6 +301,8 @@ public:
 		START_OUTGOING,		// start selected script, outbound
 		START_RECALL,		// start a recalled call
 		START_FORWARDED,	// start a forwarded call
+		START_RINGING,		// start a ringing call
+		START_HUNTING,		// start a hunting call
 		STOP_SCRIPT,
 		STOP_DISCONNECT,
 		STOP_PARENT,
@@ -440,6 +445,10 @@ public:
 		PART_DISCONNECT,
 		JOIN_PEER,
 		PEER_WAITING,
+		RELOCATE_REQUEST,	// queued event
+		RELOCATE_ACCEPT,	// hunting reply
+		RELOCATE_REJECT,	// a kind of disconnect
+		START_RELOCATE,		// start timeslot for relocation
 
 		// master control events
 
@@ -509,6 +518,20 @@ public:
 				const char *dialing;
 			}	start;
 
+			struct
+			{
+				ScriptImage *img;
+				Script::Name *scr;
+				BayonneSession *parent;
+				Line *select;
+			}	hunt;
+
+			struct
+			{
+				BayonneSession *current;
+				BayonneSession *replace;
+			}	relocate;
+
 			struct
 			{
 				const char *tid;
@@ -688,9 +711,11 @@ public:
 			{
 				const char *dial;
 				const char *exit;
-				bool dtmf;
+				bool dtmf, drop;
 				BayonneSession *peer;
-				timeout_t answer_timer;
+				timeout_t answer_timer, hunt_timer;
+				Line *select;
+				unsigned index;
 				char digits[64];
 			}	join;
 
@@ -806,6 +831,7 @@ public:
 	 * @param script to run or start.
 	 * @param caller id for this call.
 	 * @param display name for this call.
+	 * @param parent to join to.
 	 */
 	static BayonneSession *startDialing(const char *dial, 
 		const char *name, const char *caller, const char *display, BayonneSession *parent = NULL);
@@ -1369,7 +1395,7 @@ protected:
 	size_t audio_stack;
 	Audio::Level audio_level;
 
-	timeout_t pickup_timer, hangup_timer, seize_timer, ring_timer;
+	timeout_t pickup_timer, hangup_timer, seize_timer, ring_timer, hunt_timer;
 	timeout_t reset_timer, release_timer, flash_timer, interdigit_timer;
 	unsigned answer_count;
 
@@ -1614,6 +1640,14 @@ public:
 	inline timeout_t getSeizeTimer(void)
 		{return seize_timer;};
 
+	/**
+	 * Get the hunting timer.
+	 *
+	 * @return hunt timer in milliseconds.
+	 */
+	inline timeout_t getHuntTimer(void)
+		{return hunt_timer;};
+
 	/**
 	 * Get the programmed flash timer to signal trunk flash.
 	 *
@@ -1733,6 +1767,24 @@ public:
 	inline unsigned getAvail(void)
 		{return avail;}
 
+	/**
+	 * See if a given potential dialed number is an external entry
+	 * in our registrar.
+	 *
+	 * @return true if external.
+	 * @param destination to test.
+	 */
+	virtual bool isExternal(const char *dest);
+
+	/**
+	 * See if a given selected server is currently considered
+	 * reachable.  This could be used for failover.
+	 *
+	 * @return true if reachable.
+	 * @param server to test.
+	 */
+	virtual bool isReachable(const char *proxy);
+
         /**
          * Fill registration data.
          *
@@ -1967,6 +2019,7 @@ protected:
 	virtual bool enterRinging(Event *event);
 	virtual bool enterPickup(Event *event);
 	virtual bool enterSeize(Event *event);
+	virtual bool enterHunting(Event *event);
 	virtual bool enterHangup(Event *event);
 	virtual bool enterTone(Event *event);
 	virtual bool enterDTMF(Event *event);
@@ -1999,6 +2052,7 @@ protected:
 	bool stateRinging(Event *event);
 	bool statePickup(Event *event);
 	bool stateSeize(Event *event);
+	bool stateHunting(Event *event);
 	bool stateRunning(Event *event);
 	bool stateLibexec(Event *event);
 	bool stateLibreset(Event *event);
