@@ -40,6 +40,7 @@ Keydata(pairs, cfg), Mutex()
 	flash_timer = 250;
 	pickup_timer = hangup_timer = 160;
 	seize_timer = 1000;
+	hunt_timer = 16000;
 	ring_timer = 6000;
 	reset_timer = 60000;
 	release_timer = 60000;
@@ -79,6 +80,16 @@ BayonneDriver::~BayonneDriver()
 	}
 }
 
+bool BayonneDriver::isExternal(const char *ext)
+{
+	return false;
+}
+
+bool BayonneDriver::isReachable(const char *proxy)
+{
+	return true;
+}
+
 void BayonneDriver::relistIdle(void)
 {
 	highIdle = firstIdle;
