@@ -1125,7 +1125,12 @@ final:
 	else
 		state.join.answer_timer = 0;
 
-	if(!did)
+	if(event->id == START_HUNTING)
+	{
+		state.join.index = 0;
+		state.join.select = event->hunt.select;
+	}
+	else if(!did)
 		setConst("session.dialed", event->start.dialing);
 
 	return scr;
