@@ -1499,6 +1499,44 @@ bool BayonneSession::stateIdle(Event *event)
 	case START_DIRECT:
 		type = DIRECT;
 		goto attach;
+	case START_RINGING:
+		type = RINGING;
+		switch(iface)
+		{
+		case IF_INET:
+			if(!event->start.dialing)
+			{
+				purge();
+				BayonneDriver::add(this);
+				return false;
+			}
+			goto seize;
+			break;
+		case IF_NONE:
+			if(event->start.dialing)
+			{
+				purge();
+				BayonneDriver::add(this);
+				return false;
+			}
+			goto seize;
+		default:
+			purge();
+			BayonneDriver::add(this);
+			type = NONE;
+			return false;
+		}
+	case START_HUNTING:
+		type = RINGING;
+		if(attachStart(event))
+			setState(STATE_HUNTING);
+		else
+		{
+			type = NONE;
+			slog.error("%s: hunt failed", logname);
+			purge();
+		}
+		return true;			
 	case START_INCOMING:
 		type = INCOMING;
 
@@ -1534,6 +1572,7 @@ attach:
 		default:
 			break;
 		}
+seize:
 		if(attachStart(event))
 		{
 			setState(STATE_SEIZE);
@@ -1543,7 +1582,7 @@ attach:
 		purge();
 		BayonneDriver::add(this);
 		type = NONE;
-		return true;
+		return false;
 	default:
 		return enterCommon(event);
 	}
@@ -1599,6 +1638,101 @@ running:
 	return true;
 }		
 
+bool BayonneSession::stateHunting(Event *event)
+{
+	const char *cp;
+	unsigned idx;
+
+	if(event->id == ENTER_STATE)
+	{
+		type = RINGING;
+		state.join.index = 0;
+		incOutgoingAttempts();
+		state.join.hunt_timer = driver->getHuntTimer();
+	}
+
+	if(event->id != ENTER_HUNTING)
+		if(enterHunting(event))
+			return true;
+
+	switch(event->id)
+	{
+	case ENTER_STATE:
+		setOffhook(true);
+		event->id = ENTER_HUNTING;
+		return true;
+	case EXIT_HUNTING:
+		state.join.drop = true;
+		startTimer(driver->getHangupTimer());
+		return true;
+	case DIAL_CONNECT:
+		setConst("session.dialed", state.join.dial);
+		seizure = CHILD_RUNNING;
+		setConnecting();
+		return true;
+	case LINE_DISCONNECT:
+	case TONE_START:
+		return true;
+	case DIAL_FAX:
+		setConst("session.dialed", state.join.dial);
+		seizure = CHILD_FAX;
+		setConnecting("hunt:faxout");
+		return true;
+	case DIAL_PAM:
+		setConst("session.dialed", state.join.dial);
+		seizure = CHILD_RUNNING;
+		setConnecting("call:machine");
+		return true;		
+	case TIMER_EXPIRED:
+		if(state.join.drop)
+		{
+			event->id = ENTER_HUNTING;
+			state.join.drop = false;
+			return true;
+		}			
+	case CALL_FAILURE:
+	case DIAL_FAILED:
+	case DIAL_BUSY:
+	case DIAL_INVALID:
+		event->id = EXIT_HUNTING;
+		return true;
+	case ENTER_HUNTING:
+hunting:
+		state.join.drop = false;
+		while(state.join.select)
+		{
+			idx = state.join.index++;
+			cp = state.join.select->args[idx];
+			if(cp)
+			{
+				++state.join.index;
+				break;
+			}
+			state.join.select = state.join.select->next;
+			state.join.index = 0;
+		}		
+		if(state.join.dial && state.join.select)
+		{
+			if(enterHunting(event))
+			{
+				startTimer(state.join.hunt_timer);
+				return true;
+			}
+			goto hunting;
+		}
+		seizure = CHILD_FAILED;
+		if(scriptEvent("call:hunting"))
+		{
+			setRunning();
+			return true;
+		}
+		setState(STATE_HANGUP);
+		return true;		
+	default:
+		return enterCommon(event);
+	}
+}
+
 bool BayonneSession::stateSeize(Event *event)
 {
 	char evtname[96];
@@ -2223,6 +2357,11 @@ bool BayonneSession::enterSeize(Event *event)
 	return false;
 }
 
+bool BayonneSession::enterHunting(Event *event)
+{
+	return false;
+}
+
 bool BayonneSession::enterHangup(Event *event)
 {
 	return false;
