@@ -278,6 +278,81 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024 + 8192)
 		server->setValue("sip.conf", CONFIG_FILES "/sip.conf");
 }
 
+bool Driver::isReachable(const char *proxy)
+{
+	char buf[128];
+	bool rtn = false;
+	ScriptImage *img;
+	Registry *reg;
+	char *p;
+
+	if(!proxy)
+		return false;
+
+	if(strchr(proxy, '@'))
+		proxy = strchr(proxy, '@') + 1;
+	else if(!strnicmp(proxy, "sip:4", 4))
+		proxy += 4;
+
+	img = useImage();
+	if(!img)
+		return false;
+
+	snprintf(buf, sizeof(buf), "sip.%s", proxy);
+	p = strrchr(buf, ':');
+	if(p && !stricmp(p, ":5060"))
+		*p = 0;
+	
+	reg = (Registry *)img->getPointer(buf);
+	if(reg && reg->isActive())
+	{
+		if(!reg->call_limit || reg->active_calls < reg->call_limit)
+			rtn = true;
+	}
+
+	endImage(img);
+	return rtn;
+}
+
+bool Driver::isExternal(const char *ext)
+{
+	char buf[65];
+	ScriptImage *img;
+	Registry *reg;
+	bool rtn = false;
+	Name *scr;
+
+	if(!ext)
+		return false;
+
+	if(strchr(ext, '@'))
+		return false;
+
+	img = useImage();
+	if(!img)
+		return false;
+
+	if(!strnicmp(ext, "sip:", 4))
+		ext += 4;
+
+	snprintf(buf, sizeof(buf), "uri.%s", ext);
+	reg = (Registry *)img->getPointer(buf);
+	if(!reg)
+	{
+		snprintf(buf, sizeof(buf), "sip::%s", ext);
+		scr = img->getScript(buf);
+		if(scr && scr->select)
+		{
+			snprintf(buf, sizeof(buf), "uri.%s", scr->select->args[0]);
+			reg = (Registry *)img->getPointer(buf);
+		}
+	}
+	if(reg && !strnicmp(reg->type, "ext", 3))
+		rtn = true;
+	endImage(img);
+	return rtn;
+}
+
 unsigned Driver::getRegistration(regauth_t *data, unsigned count)
 {
 	unsigned idx = 0;
