@@ -160,6 +160,8 @@ public:
 
 	void setAuthentication(Registry *reg, osip_message_t *response);
 	bool getAuthentication(Session *s, osip_message_t *response);
+	bool isExternal(const char *ext);
+	bool isReachable(const char *proxy);
 
 	void run(void);
 
