@@ -26,6 +26,23 @@ AudioBase(&s->info),
 TimerPort(), Mutex()
 {
         session = s;
+	dtmf = NULL;
+	silent_frame = NULL;
+	silent_encoded = NULL;
+	pbuffer = NULL;
+	buffer = NULL;
+	lbuffer = NULL;
+
+	newSession();
+}
+
+void RTPStream::newSession(void)
+{
+	endSession();
+
+	setTimer(0);
+	memcpy(&info, &session->info, sizeof(info));
+
         dropInbound = false;
         oTimestamp = 0;
 	source = NULL;
@@ -55,16 +72,37 @@ TimerPort(), Mutex()
 RTPStream::~RTPStream()
 {
 	terminate();
-	delete[] silent_frame;
-	delete[] silent_encoded;
-	delete[] lbuffer;
-	delete[] buffer;
-	delete[] pbuffer;
+	endSession();
+	endSocket();
+}
+
+void RTPStream::endSession(void)
+{
+	setSource(NULL);
+	setSink(NULL);
+	setTone(NULL);
+
+	if(silent_frame)
+		delete[] silent_frame;
+	if(silent_encoded)
+		delete[] silent_encoded;
+	if(lbuffer)
+		delete[] lbuffer;
+	if(buffer)
+		delete[] buffer;
+	if(pbuffer)
+		delete[] pbuffer;
+	silent_frame = NULL;
+	silent_encoded = NULL;
+	lbuffer = NULL;
+	buffer = NULL;
+	pbuffer = NULL;
 	if(dtmf)
 	{
 		delete dtmf;
 		dtmf = NULL;
 	}
+	endQueue();
 }
 
 void RTPStream::start(void)
@@ -305,6 +343,20 @@ void RTPStream::peerAudio(Encoded encoded, bool linear)
 }
 
 void RTPStream::run(void)
+{
+	for(;;)
+	{
+		if(session->rtp_flag)
+		{
+			slog.debug("%s: going active", session->getLogname());
+			runActive();
+		}
+		else
+			Thread::sleep(50);
+	}
+}
+
+void RTPStream::runActive(void)
 {
         size_t r, n;
         size_t size = info.framesize;
@@ -334,6 +386,12 @@ void RTPStream::run(void)
 	setCancel(cancelDeferred);
         for(;;)
         {
+		if(!session->rtp_flag)
+		{
+			slog.debug("%s: going passive", session->getLogname());
+			return;
+		}
+
 		silent = true;
 		if(dtmfdigits)
 		{
@@ -571,7 +629,10 @@ ssize_t RTPStream::putBuffer(Encoded data, size_t len)
         if(!oTimestamp)
                 oTimestamp = getCurrentTimestamp();
         oTimestamp += result;
-        putData(oTimestamp, (const unsigned char *)data, len);
+	if(Driver::sip.send_immediate)
+		sendImmediate(oTimestamp, (const unsigned char *)data, len);
+	else
+	        putData(oTimestamp, (const unsigned char *)data, len);
         return (ssize_t)len;
 }
 
@@ -582,7 +643,12 @@ void RTPStream::put2833(struct dtmf2833 *data)
         if(!oTimestamp)
                 oTimestamp = getCurrentTimestamp();
         oTimestamp += result;
-        putData(oTimestamp, (const unsigned char *)data, sizeof(struct dtmf2833));
+	if(Driver::sip.send_immediate)
+		sendImmediate(oTimestamp, (const unsigned char *)data, 
+			sizeof(struct dtmf2833));
+	else
+	        putData(oTimestamp, (const unsigned char *)data, 
+			sizeof(struct dtmf2833));
 }
 
 ssize_t RTPStream::getBuffer(Encoded data, size_t len)
