@@ -273,24 +273,66 @@ bool Session::enterSeize(Event *event)
 	char cbuf[65];
 	char sdp[512];
 	const char *rtpmap = NULL;
-	const char *route;
+	const char *route = NULL;
         const char *lp = driver->getLast("localip");
 	BayonneSession *parent = Bayonne::getSid(var_pid);
 	const char *caller = NULL;
+	Name *scr;
+	unsigned idx;
 
 	switch(event->id)
 	{
 	case ENTER_STATE:
+		route = Driver::sip.getLast("outbound");
+		cp = getSymbol("session.dialed");
+		if(cp && !strchr(cp, '@') && !route)
+		{
+			if(!strnicmp(cp, "sip:", 4))
+				cp += 4;
+
+			snprintf(cbuf, sizeof(cbuf), "sip::%s", cp);
+			scr = img->getScript(cbuf);
+			if(scr && scr->select)
+				state.join.select = scr->select;
+			else
+				goto single;
+
+			state.join.index = 0;
+			while(state.join.select)
+			{
+				idx = state.join.index++;
+				cp = state.join.select->args[idx];
+				if(!cp)
+				{
+					state.join.select =
+						state.join.select->next;
+					state.join.index = 0;
+					continue;
+				}
+				snprintf(buf, sizeof(buf), "uri.%s", cp);
+				reg = (Registry *)img->getPointer(buf);
+				if(!reg)
+					continue;
+				if(strnicmp(reg->type, "ext", 3))
+					goto single;
+				if(!reg->isActive())
+					continue;
+				goto dialer;
+			}
+		}
+single:
 		cp = getSymbol("session.dialed");
 		if(!cp)
 		{
 			event->id = DIAL_FAILED;
 			return false;
 		}
-		route = Driver::sip.getLast("outbound");
 forward:
 		if(!strchr(cp, '@') && !route)
 		{
+			if(!strnicmp(cp, "sip:", 4))
+				cp += 4;
+
 			snprintf(buf, sizeof(buf), "uri.%s", cp);
 			reg = (Registry *)img->getPointer(buf);
 			if(reg)
@@ -309,6 +351,7 @@ forward:
 					event->id = DIAL_FAILED;
 					return false;
 				}
+dialer:
 				if(reg->call_limit && reg->active_calls >= reg->call_limit)
 				{
 					event->id = DIAL_BUSY;
