@@ -24,6 +24,7 @@ Session::Session(timeslot_t ts, unsigned sc) :
 BayonneSession(&Driver::soundcard, ts),
 TimerPort()
 {
+	ad = NULL;
 	dev = sc;
 #ifndef	WIN32
 	if(getppid() > 1)
@@ -40,6 +41,16 @@ Session::~Session()
 {
 }
 
+void Session::clrAudio(void)
+{
+	BayonneSession::clrAudio();
+	if(ad)
+	{
+		delete ad;
+		ad = NULL;
+	}
+}
+
 timeout_t Session::getRemaining(void)
 {
 	return TimerPort::getTimer();
